@@ -4,7 +4,7 @@ import boto3
 import jinja2
 import re
 from botocore.exceptions import ClientError
-from email.MIMEMultipart import MIMEMultipart
+from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 from email.mime.application import MIMEApplication
 
@@ -121,6 +121,9 @@ class Email(object):
             raise Exception('Size of file %s overreach max capacity, '
                             'file ignored.' % os.path.basename(file))
 
+    def text(self, text):
+        self._msg.attach(MIMEText(self.text))
+
     def set_paremeters(self):
         p = {"RawMessage": {'Data': self._msg.as_string(), },
              "Source": self._from_addr}
